@@ -225,15 +225,15 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
   if (!t->new)
 		return;
 
-  if (only_inbox && !t->is_inbox)
+  if (only_inbox && !(t->is_inbox))
   {
-    g_debug ("Not inbox");
+    g_debug ("EI: %s is not an inbox", t->uri);
     return;
   }
 
   if (evolution_is_focused ())
-  {
-    g_debug ("Evolution is focused");
+{
+    g_debug ("EI: Evolution is focused");
     return;
   }
 
@@ -276,7 +276,7 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
       }
     else
       {
-        g_warning ("Unable to find account that matches %s", t->uri);
+        g_warning ("EI: Unable to find account that matches %s", t->uri);
       }
     }
 
@@ -312,7 +312,7 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
 
     if (error)
     {
-      g_warning ("Could not update: %s", error->message);
+      g_warning ("EI: Could not update: %s", error->message);
       g_error_free (error);
     }
   }
@@ -330,7 +330,7 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
                            CA_PROP_CANBERRA_CACHE_CONTROL, "permanent",
                            NULL);
 
-    g_warning ("Unable to play sound: %s\n", ca_strerror (ret));
+    g_warning ("EI: Unable to play sound: %s\n", ca_strerror (ret));
   }
 
   g_static_mutex_unlock (&mlock);
@@ -356,7 +356,7 @@ org_gnome_mail_read_notify (EPlugin *ep, EMEventTargetMessage *t)
                                        INDICATE_INDICATOR_MESSAGES_PROP_ATTENTION,
                                        "false");
 
-      g_debug ("Setting %s to 0 unread messages",
+      g_debug ("EI: Setting %s to 0 unread messages",
                indicate_indicator_get_property (indicator, "name"));
 
     }
@@ -475,7 +475,7 @@ create_indicator (const gchar *url, const gchar *name)
   g_signal_connect (indicator, "user-display",
                     G_CALLBACK (show_evolution), NULL);
 
-  g_debug ("New Indicator: %s %s", name, url);
+  g_debug ("EI: New Indicator: %s %s", name, url);
 
   return indicator;
 }
@@ -562,7 +562,7 @@ update_accounts (void)
                                     &error);
   if (accounts == NULL || error)
     {
-      g_warning ("Unable to determine number of accounts, "
+      g_warning ("EI: Unable to determine number of accounts, "
                  "defaulting to '1' (%s)",
                  error ? error->message : "unknown");
       if (error)
@@ -610,7 +610,7 @@ update_accounts (void)
                   pop_indicator = create_indicator ("pop:",
                                                   g_dgettext ("evolution-2.28",
                                                                 "Inbox"));
-                  g_debug ("New Inbox inidicator");
+                  g_debug ("EI: New Inbox indicator");
                 }
               indicator = pop_indicator;
             }
@@ -628,7 +628,7 @@ update_accounts (void)
               indicator = create_indicator (data.url, data.name);
               indicators = g_slist_append (indicators, indicator);
 
-              g_debug ("New account: %s (%s)", data.name, data.url);
+              g_debug ("EI: New account: %s (%s)", data.name, data.url);
             }
 
           if (!data.enabled)
@@ -660,7 +660,7 @@ update_accounts (void)
       g_slist_free (accounts);
     }
 
-  g_debug ("Number of email accounts: %d", n_accounts);
+  g_debug ("EI: Number of email accounts: %d", n_accounts);
 }
 
 static void
@@ -680,7 +680,7 @@ command_item_activate (DbusmenuMenuitem * mi, guint timestamp, gpointer user_dat
 {
 	gchar * command = (gchar *)user_data;
 	if (!g_spawn_command_line_async(command, NULL)) {
-		g_warning("Unable to execute command '%s'", command);
+		g_warning("EI: Unable to execute command '%s'", command);
 	}
 	return;
 }
@@ -702,7 +702,7 @@ e_plugin_lib_enable (EPlugin *ep, int enable)
       ret = ca_context_create (&canberra_cxt);
       if (ret)
       {
-        g_warning ("Canberra Init Error: %s", ca_strerror (ret));
+        g_warning ("EI: Canberra Init Error: %s", ca_strerror (ret));
       }
       else
       {
@@ -713,7 +713,7 @@ e_plugin_lib_enable (EPlugin *ep, int enable)
                                        NULL);
         if (ret)
         {
-          g_warning ("Unable to set props: %s\n", ca_strerror (ret));
+          g_warning ("EI: Unable to set props: %s\n", ca_strerror (ret));
         }
       }
     }
@@ -854,7 +854,7 @@ org_gnome_get_prefs (EPlugin *ep, EConfigHookItemFactoryData *data)
 {
   GtkWidget *vbox, *frame=NULL, *check;
   
-  g_print ("EI: MAIL PREFS");
+  g_debug ("EI: MAIL PREFS");
 
 	if (data->old)
     return data->old;
@@ -862,7 +862,7 @@ org_gnome_get_prefs (EPlugin *ep, EConfigHookItemFactoryData *data)
   frame = data->parent;
   while (!GTK_IS_FRAME (frame))
   {
-    frame = frame->parent;
+    frame = gtk_widget_get_parent (frame);
 
     if (GTK_IS_WINDOW (frame) || !GTK_IS_WIDGET (frame))
       break;
@@ -875,9 +875,9 @@ org_gnome_get_prefs (EPlugin *ep, EConfigHookItemFactoryData *data)
     gchar *str1;
     gchar *str2;
 
-    frame = (GtkWidget*)data->parent->parent->parent;
+    frame = gtk_widget_get_parent (gtk_widget_get_parent (gtk_widget_get_parent ((GtkWidget*)data)));
 
-    gtk_box_reorder_child (GTK_BOX (frame->parent), frame, 0);
+    gtk_box_reorder_child (GTK_BOX (gtk_widget_get_parent (frame)), frame, 0);
 
     box = gtk_hbox_new (FALSE, 0);
     gtk_frame_set_label_widget (GTK_FRAME (frame), box);
@@ -961,7 +961,7 @@ show_evolution (gpointer arg0, guint timestamp, gpointer arg1)
 #define MAIL_ICON "evolution-mail"
   EShell *shell = e_shell_get_default ();
 
-  g_debug ("Showing Evolution to user");
+  g_debug ("EI: Showing Evolution to user");
 
   if (shell)
   {
@@ -1002,7 +1002,7 @@ show_evolution (gpointer arg0, guint timestamp, gpointer arg1)
                                        INDICATE_INDICATOR_MESSAGES_PROP_ATTENTION,
                                        "false");
 
-      g_debug ("Setting %s to 0 unread messages",
+      g_debug ("EI: Setting %s to 0 unread messages",
                indicate_indicator_get_property (indicator, "name"));
 
     }
@@ -1010,7 +1010,7 @@ show_evolution (gpointer arg0, guint timestamp, gpointer arg1)
   }
   else
   {
-    g_warning ("Cannot show window, no shell");
+    g_warning ("EI: Cannot show window, no shell");
     return;
   }
 }
@@ -1046,7 +1046,7 @@ show_evolution_in_indicator_applet (void)
 
           if (error)
             {
-              g_warning ("Unable to remove blacklist file: %s", error->message);
+              g_warning ("EI: Unable to remove blacklist file: %s", error->message);
               g_error_free (error);
             }
 
@@ -1079,7 +1079,7 @@ hide_evolution_in_indicator_applet (void)
                                               &error);
           if (error)
             {
-              g_warning ("Unable to create blacklist directory: %s",
+              g_warning ("EI: Unable to create blacklist directory: %s",
                          error->message);
               g_error_free (error);
               g_object_unref (dirfile);
@@ -1090,7 +1090,7 @@ hide_evolution_in_indicator_applet (void)
         }
       else
         {
-          g_warning ("Unable to create blacklist directory: Unable to create "
+          g_warning ("EI: Unable to create blacklist directory: Unable to create "
                      "GFile for path %s", bdir);
           g_free (bdir);
           g_free (bpath);
@@ -1111,11 +1111,11 @@ hide_evolution_in_indicator_applet (void)
                            -1,
                            &error))
     {
-      g_debug ("Successfully wrote blacklist file to %s", bpath);
+      g_debug ("EI: Successfully wrote blacklist file to %s", bpath);
     }
   else
     {
-      g_debug ("Unable to write blacklist file to %s: %s",
+      g_debug ("EI: Unable to write blacklist file to %s: %s",
                bpath,
                error ? error->message : "Unknown");
       if (error)
